Visual Poem (PDF,PNG) Generation (pdf.py)
=========================================

   |

These functions allow for the creation of all currently supported types of visual poems.

.. automodule:: generativepoetry.pdf
   :members:
